fortis
library
Classes
-
AesAuthCipher
-
A cipher for AES authenticated modes: AesMode.gcm, AesMode.ccm.
-
AesAuthModeBuilder
-
Sealed base for authenticated-mode builders (AesMode.gcm, AesMode.ccm).
-
AesAuthPayload
-
The output of an AES authenticated encryption operation
(AesMode.gcm, AesMode.ccm).
-
AesBuilder
-
Builder for AES key generation and cipher configuration.
-
AesCbcModeBuilder
-
Builder for AesMode.cbc. Exposes padding.
-
AesCcmModeBuilder
-
Builder for AesMode.ccm. Exposes aad, ivSize, and tagSize.
-
AesCipher
-
A symmetric AES cipher that encrypts and decrypts with the same key.
-
AesEcbCipher
-
A cipher for AES in AesMode.ecb mode.
-
AesEcbModeBuilder
-
Builder for AesMode.ecb. Exposes padding.
-
AesGcmModeBuilder
-
Builder for AesMode.gcm. Exposes aad and ivSize.
-
AesModeBuilder
-
Sealed base for mode-specific AES builders.
-
AesPayload
-
The output of an AES non-authenticated encryption operation
(AesMode.cbc, AesMode.ctr, AesMode.cfb, AesMode.ofb).
-
AesStandardCipher
-
A cipher for AES modes that use an IV but do not authenticate:
AesMode.cbc, AesMode.ctr, AesMode.cfb, AesMode.ofb.
-
AesStreamModeBuilder
-
Builder for stream modes (AesMode.ctr, AesMode.cfb, AesMode.ofb).
No user-configurable padding — stream modes don't use padding.
-
EcdhBuilder
-
A fluent builder for ECDH key agreement operations.
-
EcdhKeyDerivation
-
Performs ECDH key agreement and key derivation.
-
Fortis
-
Entry point for the Fortis cryptography library.
-
FortisAesKey
-
An AES symmetric key used for both encryption and decryption.
-
FortisEcdhKeyPair
-
A matching pair of ECDH publicKey and privateKey.
-
FortisEcdhPrivateKey
-
An ECDH private key used for key agreement.
-
FortisEcdhPublicKey
-
An ECDH public key used for key agreement.
-
FortisRsaKeyPair
-
A matching pair of RSA publicKey and privateKey.
-
FortisRsaPrivateKey
-
An RSA private key used for decryption.
-
FortisRsaPublicKey
-
An RSA public key used for encryption.
-
RsaBuilder<P extends RsaBuilderPaddingState, H extends RsaBuilderHashState>
-
A fluent builder for RSA operations.
-
RsaBuilderHashSet
-
Indicates that RsaBuilder.hash has been called.
-
RsaBuilderHashState
-
Marker base for the hash configuration state.
-
RsaBuilderHashUnset
-
Indicates that RsaBuilder.hash has not been called yet.
-
RsaBuilderPaddingSet
-
Indicates that RsaBuilder.padding has been called.
-
RsaBuilderPaddingState
-
Marker base for the padding configuration state.
-
RsaBuilderPaddingUnset
-
Indicates that RsaBuilder.padding has not been called yet.
-
RsaDecrypter
-
Decrypts data using an RSA private key.
-
RsaEncrypter
-
Encrypts data using an RSA public key.