Indicates that RsaBuilder.padding has been called.
See also:
- RsaBuilderReady, the extension this marker helps unlock.
- RsaBuilderHashSet, the other half of that requirement.
- Inheritance
-
- Object
- RsaBuilderPaddingState
- RsaBuilderPaddingSet
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited