Indicates that RsaBuilder.padding has not been called yet.
See also:
- RsaBuilder, which carries this marker as a type parameter.
- RsaBuilderPaddingSet, the state that replaces this one.
- Inheritance
-
- Object
- RsaBuilderPaddingState
- RsaBuilderPaddingUnset
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited